@@ -1,6 +1,7 @@
 """Camoufox browser manager - privacy-focused Firefox automation."""
 
-from typing import Optional
+from pathlib import Path
+from typing import Optional, TypeAlias
 
 import camoufox
 from camoufox.addons import DefaultAddons
@@ -9,6 +10,8 @@ from camoufox.locale import ALLOW_GEOIP, download_mmdb
 from camoufox.pkgman import CamoufoxFetcher, camoufox_path
 from playwright.async_api import Browser, BrowserContext, Page
 
+_MIN_VIEWPORT_DIMENSION = 640
+
 from code_puppy.messaging import emit_info
 
 
@@ -38,6 +41,9 @@ class CamoufoxManager:
         self.block_webrtc = True  # Block WebRTC for privacy
         self.humanize = True  # Add human-like behavior
 
+        # Persistent profile directory for consistent browser state across runs
+        self.profile_dir = self._get_profile_directory()
+
     @classmethod
     def get_instance(cls) -> "CamoufoxManager":
         """Get the singleton instance."""
@@ -45,6 +51,16 @@ class CamoufoxManager:
             cls._instance = cls()
         return cls._instance
 
+    def _get_profile_directory(self) -> Path:
+        """Get or create the persistent profile directory.
+
+        Returns a Path object pointing to ~/.code_puppy/camoufox_profile
+        where browser data (cookies, history, bookmarks, etc.) will be stored.
+        """
+        profile_path = Path.home() / ".code_puppy" / "camoufox_profile"
+        profile_path.mkdir(parents=True, exist_ok=True)
+        return profile_path
+
     async def async_initialize(self) -> None:
         """Initialize Camoufox browser."""
         if self._initialized:
@@ -68,30 +84,40 @@ class CamoufoxManager:
 
     async def _initialize_camoufox(self) -> None:
         """Try to start Camoufox with the configured privacy settings."""
+        emit_info(f"[cyan]📁 Using persistent profile: {self.profile_dir}[/cyan]")
+
         camoufox_instance = camoufox.AsyncCamoufox(
             headless=self.headless,
             block_webrtc=self.block_webrtc,
             humanize=self.humanize,
             exclude_addons=list(DefaultAddons),
+            persistent_context=True,
+            user_data_dir=str(self.profile_dir),
             addons=[],
         )
-        self._browser = await camoufox_instance.start()
-        self._context = await self._browser.new_context(
-            viewport={"width": 1920, "height": 1080},
-            ignore_https_errors=True,
-        )
-        page = await self._context.new_page()
-        await page.goto(self.homepage)
+
+        self._browser = camoufox_instance.browser
+        # Use persistent storage directory for browser context
+        # This ensures cookies, localStorage, history, etc. persist across runs
+        if not self._initialized:
+            self._context = await camoufox_instance.start()
+            self._initialized = True
+            # Do not auto-open a page here to avoid duplicate windows/tabs.
 
     async def get_current_page(self) -> Optional[Page]:
-        """Get the currently active page."""
+        """Get the currently active page. Lazily creates one if none exist."""
         if not self._initialized or not self._context:
             await self.async_initialize()
 
-        if self._context:
-            pages = self._context.pages
-            return pages[0] if pages else None
-        return None
+        if not self._context:
+            return None
+
+        pages = self._context.pages
+        if pages:
+            return pages[0]
+
+        # Lazily create a new blank page without navigation
+        return await self._context.new_page()
 
     async def new_page(self, url: Optional[str] = None) -> Page:
         """Create a new page and optionally navigate to URL."""
@@ -140,9 +166,21 @@ class CamoufoxManager:
         return self._context.pages
 
     async def _cleanup(self) -> None:
-        """Clean up browser resources."""
+        """Clean up browser resources and save persistent state."""
         try:
+            # Save browser state before closing (cookies, localStorage, etc.)
             if self._context:
+                try:
+                    storage_state_path = self.profile_dir / "storage_state.json"
+                    await self._context.storage_state(path=str(storage_state_path))
+                    emit_info(
+                        f"[green]💾 Browser state saved to {storage_state_path}[/green]"
+                    )
+                except Exception as e:
+                    emit_info(
+                        f"[yellow]Warning: Could not save storage state: {e}[/yellow]"
+                    )
+
                 await self._context.close()
                 self._context = None
             if self._browser:
