@@ -18,23 +18,7 @@ from code_puppy.messaging import (
     emit_system_message,
     emit_warning,
 )
-from code_puppy.tools.common import generate_group_id, should_ignore_path
-
-# Add token checking functionality
-try:
-    from code_puppy.token_utils import get_tokenizer
-    from code_puppy.tools.token_check import token_guard
-except ImportError:
-    # Fallback for when token checking modules aren't available
-    def get_tokenizer():
-        # Simple token estimation - no longer using tiktoken
-        return None
-
-    def token_guard(num_tokens):
-        if num_tokens > 10000:
-            raise ValueError(
-                f"Token count {num_tokens} exceeds safety limit of 10,000 tokens"
-            )
+from code_puppy.tools.common import generate_group_id
 
 
 # Pydantic models for tool return types
@@ -126,9 +110,8 @@ def is_project_directory(directory):
 def _list_files(
     context: RunContext, directory: str = ".", recursive: bool = True
 ) -> ListFileOutput:
-    import subprocess
-    import tempfile
     import shutil
+    import subprocess
     import sys
 
     results = []
@@ -136,26 +119,30 @@ def _list_files(
 
     # Build string representation
     output_lines = []
-    
-    directory_listing_header = "\n[bold white on blue] DIRECTORY LISTING [/bold white on blue]"
+
+    directory_listing_header = (
+        "\n[bold white on blue] DIRECTORY LISTING [/bold white on blue]"
+    )
     output_lines.append(directory_listing_header)
-    
+
     directory_info = f"\U0001f4c2 [bold cyan]{directory}[/bold cyan] [dim](recursive={recursive})[/dim]\n"
     output_lines.append(directory_info)
-    
+
     divider = "[dim]" + "─" * 100 + "\n" + "[/dim]"
     output_lines.append(divider)
-    
+
     if not os.path.exists(directory):
-        error_msg = f"[red bold]Error:[/red bold] Directory '{directory}' does not exist"
+        error_msg = (
+            f"[red bold]Error:[/red bold] Directory '{directory}' does not exist"
+        )
         output_lines.append(error_msg)
-        
+
         output_lines.append(divider)
         return ListFileOutput(content="\n".join(output_lines))
     if not os.path.isdir(directory):
         error_msg = f"[red bold]Error:[/red bold] '{directory}' is not a directory"
         output_lines.append(error_msg)
-        
+
         output_lines.append(divider)
         return ListFileOutput(content="\n".join(output_lines))
 
@@ -165,11 +152,11 @@ def _list_files(
         if not is_project_directory(directory):
             warning_msg = "[yellow bold]Warning:[/yellow bold] 🏠 Detected home directory - limiting to non-recursive listing for performance"
             output_lines.append(warning_msg)
-            
+
             info_msg = f"[dim]💡 To force recursive listing in home directory, use list_files('{directory}', recursive=True) explicitly[/dim]"
             output_lines.append(info_msg)
             recursive = False
-            
+
     # Create a temporary ignore file with our ignore patterns
     ignore_file = None
     try:
@@ -190,50 +177,56 @@ def _list_files(
                 if os.path.exists(venv_rg_exe_path):
                     rg_path = venv_rg_exe_path
                     break
-        
+
         if not rg_path:
-            error_msg = f"[red bold]Error:[/red bold] ripgrep (rg) not found. Please install ripgrep to use this tool."
+            error_msg = "[red bold]Error:[/red bold] ripgrep (rg) not found. Please install ripgrep to use this tool."
             output_lines.append(error_msg)
             return ListFileOutput(content="\n".join(output_lines))
-            
+
         # Build command for ripgrep --files
         cmd = [rg_path, "--files"]
-        
+
         # For non-recursive mode, we'll limit depth after getting results
         if not recursive:
             cmd.extend(["--max-depth", "1"])
-            
+
         # Add ignore patterns to the command via a temporary file
         from code_puppy.tools.common import IGNORE_PATTERNS
-        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.ignore') as f:
+
+        with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".ignore") as f:
             ignore_file = f.name
             for pattern in IGNORE_PATTERNS:
                 f.write(f"{pattern}\n")
-        
+
         cmd.extend(["--ignore-file", ignore_file])
         cmd.append(directory)
-        
+
         # Run ripgrep to get file listing
         result = subprocess.run(cmd, capture_output=True, text=True, timeout=30)
-        
+
         # Process the output lines
-        files = result.stdout.strip().split('\n') if result.stdout.strip() else []
-        
+        files = result.stdout.strip().split("\n") if result.stdout.strip() else []
+
         # Create ListedFile objects with metadata
-        for file_path in files:
-            if not file_path:  # Skip empty lines
+        for full_path in files:
+            if not full_path:  # Skip empty lines
                 continue
-                
-            full_path = os.path.join(directory, file_path)
-            
+
             # Skip if file doesn't exist (though it should)
             if not os.path.exists(full_path):
                 continue
-                
+
+            # Extract relative path from the full path
+            if full_path.startswith(directory):
+                file_path = full_path[len(directory) :].lstrip(os.sep)
+            else:
+                file_path = full_path
+
             # For non-recursive mode, skip files in subdirectories
+            # Only check the relative path, not the full path
             if not recursive and os.sep in file_path:
                 continue
-                
+
             # Check if path is a file or directory
             if os.path.isfile(full_path):
                 entry_type = "file"
@@ -244,19 +237,19 @@ def _list_files(
             else:
                 # Skip if it's neither a file nor directory
                 continue
-                
+
             try:
                 # Get stats for the entry
                 stat_info = os.stat(full_path)
                 actual_size = stat_info.st_size
-                
+
                 # For files, we use the actual size; for directories, we keep size=0
                 if entry_type == "file":
                     size = actual_size
-                
-                # Calculate depth
+
+                # Calculate depth based on the relative path
                 depth = file_path.count(os.sep)
-                
+
                 # Add directory entries if needed for files
                 if entry_type == "file":
                     dir_path = os.path.dirname(file_path)
@@ -264,9 +257,12 @@ def _list_files(
                         # Add directory path components if they don't exist
                         path_parts = dir_path.split(os.sep)
                         for i in range(len(path_parts)):
-                            partial_path = os.sep.join(path_parts[:i+1])
+                            partial_path = os.sep.join(path_parts[: i + 1])
                             # Check if we already added this directory
-                            if not any(f.path == partial_path and f.type == "directory" for f in results):
+                            if not any(
+                                f.path == partial_path and f.type == "directory"
+                                for f in results
+                            ):
                                 results.append(
                                     ListedFile(
                                         path=partial_path,
@@ -276,7 +272,7 @@ def _list_files(
                                         depth=partial_path.count(os.sep),
                                     )
                                 )
-                
+
                 # Add the entry (file or directory)
                 results.append(
                     ListedFile(
@@ -290,12 +286,45 @@ def _list_files(
             except (FileNotFoundError, PermissionError, OSError):
                 # Skip files we can't access
                 continue
+
+        # In non-recursive mode, we also need to explicitly list directories in the target directory
+        # ripgrep's --files option only returns files, not directories
+        if not recursive:
+            try:
+                entries = os.listdir(directory)
+                for entry in entries:
+                    full_entry_path = os.path.join(directory, entry)
+                    # Skip if it doesn't exist or if it's a file (since files are already listed by ripgrep)
+                    if not os.path.exists(full_entry_path) or os.path.isfile(
+                        full_entry_path
+                    ):
+                        continue
+
+                    # For non-recursive mode, only include directories that are directly in the target directory
+                    if os.path.isdir(full_entry_path):
+                        # Create a ListedFile for the directory
+                        results.append(
+                            ListedFile(
+                                path=entry,
+                                type="directory",
+                                size=0,
+                                full_path=full_entry_path,
+                                depth=0,
+                            )
+                        )
+            except (FileNotFoundError, PermissionError, OSError):
+                # Skip directories we can't access
+                pass
     except subprocess.TimeoutExpired:
-        error_msg = f"[red bold]Error:[/red bold] List files command timed out after 30 seconds"
+        error_msg = (
+            "[red bold]Error:[/red bold] List files command timed out after 30 seconds"
+        )
         output_lines.append(error_msg)
         return ListFileOutput(content="\n".join(output_lines))
     except Exception as e:
-        error_msg = f"[red bold]Error:[/red bold] Error during list files operation: {e}"
+        error_msg = (
+            f"[red bold]Error:[/red bold] Error during list files operation: {e}"
+        )
         output_lines.append(error_msg)
         return ListFileOutput(content="\n".join(output_lines))
     finally:
@@ -342,30 +371,31 @@ def _list_files(
         else:
             return "\U0001f4c4"
 
+    # Count items in results
     dir_count = sum(1 for item in results if item.type == "directory")
     file_count = sum(1 for item in results if item.type == "file")
     total_size = sum(item.size for item in results if item.type == "file")
-    
+
     # Build the directory header section
     dir_name = os.path.basename(directory) or directory
     dir_header = f"\U0001f4c1 [bold blue]{dir_name}[/bold blue]"
     output_lines.append(dir_header)
-    
+
     # Sort all items by path for consistent display
     all_items = sorted(results, key=lambda x: x.path)
-    
+
     # Build file and directory tree representation
     parent_dirs_with_content = set()
     for item in all_items:
         # Skip root directory entries with no path
         if item.type == "directory" and not item.path:
             continue
-        
+
         # Track parent directories that contain files/dirs
         if os.sep in item.path:
             parent_path = os.path.dirname(item.path)
             parent_dirs_with_content.add(parent_path)
-            
+
         # Calculate indentation depth based on path separators
         depth = item.path.count(os.sep) + 1 if item.path else 0
         prefix = ""
@@ -374,10 +404,10 @@ def _list_files(
                 prefix += "\u2514\u2500\u2500 "
             else:
                 prefix += "    "
-                
+
         # Get the display name (basename) of the item
         name = os.path.basename(item.path) or item.path
-        
+
         # Add directory or file line with appropriate formatting
         if item.type == "directory":
             dir_line = f"{prefix}\U0001f4c1 [bold blue]{name}/[/bold blue]"
@@ -387,19 +417,19 @@ def _list_files(
             size_str = format_size(item.size)
             file_line = f"{prefix}{icon} [green]{name}[/green] [dim]({size_str})[/dim]"
             output_lines.append(file_line)
-    
+
     # Add summary information
     summary_header = "\n[bold cyan]Summary:[/bold cyan]"
     output_lines.append(summary_header)
-    
+
     summary_line = f"\U0001f4c1 [blue]{dir_count} directories[/blue], \U0001f4c4 [green]{file_count} files[/green] [dim]({format_size(total_size)} total)[/dim]"
     output_lines.append(summary_line)
-    
+
     final_divider = "[dim]" + "─" * 100 + "\n" + "[/dim]"
     output_lines.append(final_divider)
-    
-    # Return both the content string and the list of ListedFile objects
-    return ListFileOutput(content="\n".join(output_lines), files=results)
+
+    # Return the content string
+    return ListFileOutput(content="\n".join(output_lines))
 
 
 def _read_file(
@@ -461,13 +491,12 @@ def _read_file(
 
 
 def _grep(context: RunContext, search_string: str, directory: str = ".") -> GrepOutput:
-    import subprocess
     import json
-    import tempfile
     import os
     import shutil
+    import subprocess
     import sys
-    
+
     directory = os.path.abspath(directory)
     matches: List[MatchInfo] = []
 
@@ -490,7 +519,7 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
         # --max-filesize 5M to avoid huge files (increased from 1M)
         # --type=all to search across all recognized text file types
         # --ignore-file to obey our ignore list
-        
+
         # Find ripgrep executable - first check system PATH, then virtual environment
         rg_path = shutil.which("rg")
         if not rg_path:
@@ -508,43 +537,62 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
                 if os.path.exists(venv_rg_exe_path):
                     rg_path = venv_rg_exe_path
                     break
-        
+
         if not rg_path:
-            emit_error(f"ripgrep (rg) not found. Please install ripgrep to use this tool.", message_group=group_id)
+            emit_error(
+                "ripgrep (rg) not found. Please install ripgrep to use this tool.",
+                message_group=group_id,
+            )
             return GrepOutput(matches=[])
-            
-        cmd = [rg_path, "--json", "--max-count", "50", "--max-filesize", "5M", "--type=all"]
-        
+
+        cmd = [
+            rg_path,
+            "--json",
+            "--max-count",
+            "50",
+            "--max-filesize",
+            "5M",
+            "--type=all",
+        ]
+
         # Add ignore patterns to the command via a temporary file
         from code_puppy.tools.common import IGNORE_PATTERNS
-        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.ignore') as f:
+
+        with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".ignore") as f:
             ignore_file = f.name
             for pattern in IGNORE_PATTERNS:
                 f.write(f"{pattern}\n")
-        
+
         cmd.extend(["--ignore-file", ignore_file])
         cmd.extend([search_string, directory])
         result = subprocess.run(cmd, capture_output=True, text=True, timeout=30)
-        
+
         # Parse the JSON output from ripgrep
-        for line in result.stdout.strip().split('\n'):
+        for line in result.stdout.strip().split("\n"):
             if not line:
                 continue
             try:
                 match_data = json.loads(line)
                 # Only process match events, not context or summary
-                if match_data.get('type') == 'match':
-                    data = match_data.get('data', {})
-                    path_data = data.get('path', {})
-                    file_path = path_data.get('text', '') if path_data.get('text') else ''
-                    line_number = data.get('line_number', None)
-                    line_content = data.get('lines', {}).get('text', '') if data.get('lines', {}).get('text') else ''
-                    
+                if match_data.get("type") == "match":
+                    data = match_data.get("data", {})
+                    path_data = data.get("path", {})
+                    file_path = (
+                        path_data.get("text", "") if path_data.get("text") else ""
+                    )
+                    line_number = data.get("line_number", None)
+                    line_content = (
+                        data.get("lines", {}).get("text", "")
+                        if data.get("lines", {}).get("text")
+                        else ""
+                    )
+                    if len(line_content.strip()) > 512:
+                        line_content = line_content.strip()[0:512]
                     if file_path and line_number:
                         match_info = MatchInfo(
                             file_path=file_path,
                             line_number=line_number,
-                            line_content=line_content.strip()
+                            line_content=line_content.strip(),
                         )
                         matches.append(match_info)
                         # Limit to 50 matches total, same as original implementation
@@ -557,7 +605,7 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
             except json.JSONDecodeError:
                 # Skip lines that aren't valid JSON
                 continue
-                
+
         if not matches:
             emit_warning(
                 f"No matches found for '{search_string}' in {directory}",
@@ -568,18 +616,21 @@ def _grep(context: RunContext, search_string: str, directory: str = ".") -> Grep
                 f"Found {len(matches)} match(es) for '{search_string}' in {directory}",
                 message_group=group_id,
             )
-            
+
     except subprocess.TimeoutExpired:
-        emit_error(f"Grep command timed out after 30 seconds", message_group=group_id)
+        emit_error("Grep command timed out after 30 seconds", message_group=group_id)
     except FileNotFoundError:
-        emit_error(f"ripgrep (rg) not found. Please install ripgrep to use this tool.", message_group=group_id)
+        emit_error(
+            "ripgrep (rg) not found. Please install ripgrep to use this tool.",
+            message_group=group_id,
+        )
     except Exception as e:
         emit_error(f"Error during grep operation: {e}", message_group=group_id)
     finally:
         # Clean up the temporary ignore file
         if ignore_file and os.path.exists(ignore_file):
             os.unlink(ignore_file)
-        
+
     return GrepOutput(matches=matches)
 
 
@@ -587,13 +638,13 @@ def register_list_files(agent):
     """Register only the list_files tool."""
     from code_puppy.config import get_allow_recursion
 
-    @agent.tool(strict=False)
+    @agent.tool
     def list_files(
         context: RunContext, directory: str = ".", recursive: bool = True
     ) -> ListFileOutput:
         """List files and directories with intelligent filtering and safety features.
-        
-        This function will only allow recursive listing when the allow_recursion 
+
+        This function will only allow recursive listing when the allow_recursion
         configuration is set to true via the /set allow_recursion=true command.
 
         This tool provides comprehensive directory listing with smart home directory
@@ -635,24 +686,28 @@ def register_list_files(agent):
             - Check for errors in the response
             - Combine with grep to find specific file patterns
         """
-        warning=None
+        warning = None
         if recursive and not get_allow_recursion():
             warning = "Recursion disabled globally for list_files - returning non-recursive results"
             recursive = False
         result = _list_files(context, directory, recursive)
-        
+
         # Emit the content directly to ensure it's displayed to the user
-        emit_info(result.content, message_group=generate_group_id("list_files", directory))
-        
+        emit_info(
+            result.content, message_group=generate_group_id("list_files", directory)
+        )
         if warning:
             result.error = warning
+        if (len(result.content)) > 200000:
+            result.content = result.content[0:200000]
+            result.error = "Results truncated. This is a massive directory tree, recommend non-recursive calls to list_files"
         return result
 
 
 def register_read_file(agent):
     """Register only the read_file tool."""
 
-    @agent.tool(strict=False)
+    @agent.tool
     def read_file(
         context: RunContext,
         file_path: str = "",
@@ -710,15 +765,15 @@ def register_read_file(agent):
 def register_grep(agent):
     """Register only the grep tool."""
 
-    @agent.tool(strict=False)
+    @agent.tool
     def grep(
         context: RunContext, search_string: str = "", directory: str = "."
     ) -> GrepOutput:
         """Recursively search for text patterns across files using ripgrep (rg).
 
-        This tool leverages the high-performance ripgrep utility for fast text 
+        This tool leverages the high-performance ripgrep utility for fast text
         searching across directory trees. It searches across all recognized text file
-        types (Python, JavaScript, HTML, CSS, Markdown, etc.) while automatically 
+        types (Python, JavaScript, HTML, CSS, Markdown, etc.) while automatically
         filtering binary files and limiting results for performance.
 
         The search_string parameter supports ripgrep's full flag syntax, allowing
