@@ -4,7 +4,7 @@ Settings modal screen.
 
 from textual import on
 from textual.app import ComposeResult
-from textual.containers import Container
+from textual.containers import Container, VerticalScroll
 from textual.screen import ModalScreen
 from textual.widgets import Button, Input, Select, Static
 
@@ -27,6 +27,7 @@ class SettingsScreen(ModalScreen):
 
     #settings-form {
         height: 1fr;
+        overflow: auto;
     }
 
     .setting-row {
@@ -70,7 +71,8 @@ class SettingsScreen(ModalScreen):
     def compose(self) -> ComposeResult:
         with Container(id="settings-dialog"):
             yield Static("⚙️  Settings Configuration", id="settings-title")
-            with Container(id="settings-form"):
+            # Make the form scrollable so long content fits
+            with VerticalScroll(id="settings-form"):
                 with Container(classes="setting-row"):
                     yield Static("Puppy Name:", classes="setting-label")
                     yield Input(id="puppy-name-input", classes="setting-input")
@@ -215,6 +217,20 @@ class SettingsScreen(ModalScreen):
             # Save model selection
             if selected_model:
                 set_model_name(selected_model)
+                # Reload the active agent so model switch takes effect immediately
+                try:
+                    from code_puppy.agents import get_current_agent
+
+                    current_agent = get_current_agent()
+                    if hasattr(current_agent, "refresh_config"):
+                        try:
+                            current_agent.refresh_config()
+                        except Exception:
+                            ...
+                    current_agent.reload_code_generation_agent()
+                except Exception:
+                    # Non-fatal: settings saved; reload will happen on next run if needed
+                    pass
 
             set_config_value("yolo_mode", yolo_mode)
 
